# flask-traffic
Store and monitor site traffic.

`pip install flask-traffic`

Currently under development.

Look in the `example` directory for a working example.

[https://github.com/CheeseCake87/flask-traffic/tree/main/example](https://github.com/CheeseCake87/flask-traffic/tree/main/example)
